@@ -155,7 +155,7 @@ def test_source_netns_restart(context):
 
 def count_interfaces(ndb, target):
     return (
-        ndb.schema.fetchone(
+        ndb.task_manager.db_fetchone(
             '''
                       SELECT count(*) FROM interfaces
                       WHERE
@@ -184,33 +184,31 @@ def test_disconnect_localhost(context):
 
     #
     # lock the DB
-    with context.ndb.schema.readonly:
-        total_ifnum = context.ndb.interfaces.dump().count()
-        with context.ndb.interfaces.dump() as dump:
-            dump.select_records(target='localhost')
-            localhost_ifnum = len(tuple(dump))
-        with context.ndb.interfaces.dump() as dump:
-            dump.select_records(target=nsname)
-            nsname_ifnum = len(tuple(dump))
+    total_ifnum = context.ndb.interfaces.dump().count()
+    with context.ndb.interfaces.dump() as dump:
+        dump.select_records(target='localhost')
+        localhost_ifnum = len(tuple(dump))
+    with context.ndb.interfaces.dump() as dump:
+        dump.select_records(target=nsname)
+        nsname_ifnum = len(tuple(dump))
 
-        assert localhost_ifnum == count_interfaces(context.ndb, 'localhost')
-        assert nsname_ifnum == count_interfaces(context.ndb, nsname)
-        assert 0 < count_interfaces(context.ndb, 'localhost') < total_ifnum
-        assert 0 < count_interfaces(context.ndb, nsname) < total_ifnum
+    assert localhost_ifnum == count_interfaces(context.ndb, 'localhost')
+    assert nsname_ifnum == count_interfaces(context.ndb, nsname)
+    assert 0 < count_interfaces(context.ndb, 'localhost') < total_ifnum
+    assert 0 < count_interfaces(context.ndb, nsname) < total_ifnum
 
     context.ndb.sources.remove('localhost')
 
-    with context.ndb.schema.readonly:
-        #
-        # the number of 'localhost' interfaces must be 0 here
-        with context.ndb.interfaces.dump() as dump:
-            dump.select_records(target='localhost')
-            assert len(list(dump)) == 0
-            assert count_interfaces(context.ndb, 'localhost') == 0
-        #
-        # the number of `nsname` interfaces must remain the same as before
-        with context.ndb.interfaces.dump() as dump:
-            dump.select_records(target=nsname)
-            s = len(list(dump))
-            assert s > 0
-            assert count_interfaces(context.ndb, nsname) == s
+    #
+    # the number of 'localhost' interfaces must be 0 here
+    with context.ndb.interfaces.dump() as dump:
+        dump.select_records(target='localhost')
+        assert len(list(dump)) == 0
+        assert count_interfaces(context.ndb, 'localhost') == 0
+    #
+    # the number of `nsname` interfaces must remain the same as before
+    with context.ndb.interfaces.dump() as dump:
+        dump.select_records(target=nsname)
+        s = len(list(dump))
+        assert s > 0
+        assert count_interfaces(context.ndb, nsname) == s
